==> oe_python_template-0.2.3.tar.gz: oe_python_template-0.2.3/RELEASE_NOTES.md <==
[🧠 OE Python Template](https://oe-python-template.readthedocs.io/en/latest/)

## [0.2.3](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.2.2..v0.2.3) - 2025-03-03

### ⛰️  Features

- *(copier)* Introduce tasks - ([db540bc](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/db540bc2907710409c2a23e8a704804bc8e7edda))


## [0.2.2](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.2.1..v0.2.2) - 2025-03-02

### 📚 Documentation

- Update - ([ae71c31](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/ae71c31c917a7439dc24fe9b86c48e38cf1d4c29))


## [0.2.1](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.2.0..v0.2.1) - 2025-03-02

### 📚 Documentation

- Update - ([e718c4c](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/e718c4ca41f566e9668566a3ac8cb92b93d93904))


## [0.2.0](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.1.4..v0.2.0) - 2025-03-02

### 📚 Documentation

- Start to document the template and setup process - ([d37c39c](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/d37c39c518736301aadf1192f9a48c4cfd1ded6e))


## [0.1.4](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.1.3..v0.1.4) - 2025-03-02

### ⛰️  Features

- *(notebooks)* Introduce marimo - ([5d8eb68](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/5d8eb687da96d5111130f67079cc8cbee06ca20e))


## [0.1.3](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.1.2..v0.1.3) - 2025-03-02

### ⚙️ Miscellaneous Tasks

- Other - ([630b5b6](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/630b5b6ca7c2a388c7d1425301f88f0da6e468ad))


## [0.1.2](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.1.1..v0.1.2) - 2025-03-02

### 📚 Documentation

- On template - ([48bdcbe](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/48bdcbe863942bc7dd03bc8e71a50cae968c010c))


## [0.1.1](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.1.0..v0.1.1) - 2025-03-02

### ⚙️ Miscellaneous Tasks

- Arch - ([2cfbe81](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/2cfbe81574646e3dc5c3fa6bf07292d9bf04e1b9))


## [0.1.0](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.0.2..v0.1.0) - 2025-03-02

### ⚙️ Miscellaneous Tasks

- Fix in arch for docker images - ([be8de5b](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/be8de5b1d13587017cdb5b7ecc1bba63ea8245fb))


## [0.0.2] - 2025-03-02

### ⛰️  Features

- Various - ([5b74351](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/5b74351e71e2ca6cb7305bcabdbe802df55c4bae))
- Spike - ([21607c9](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/21607c955cd789dbee6171d287e21f45f039c392))

### 🐛 Bug Fixes

- *(Docker)* Runnability - ([164ab1f](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/164ab1fd7ec517d52587cf7f27f0051bdb6ce319))
- Initial semver - ([9f6fc12](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/9f6fc125c0e24cc0e31580de94db8beb926c8e36))
- Test - ([52faa74](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/52faa74b2d448b13dc12a4d8f706b34334643d00))
- Various - ([f99445f](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/f99445f85b346e0eb69a13c98c2ed311fd4cfafe))
- Chugging along - ([d59fa54](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/d59fa548abc38e88a4605f9588d57bbf9d70d1dc))

### 🚜 Refactor

- *(gitignore)* Section header - ([4ec3972](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/4ec39725978a1e2a3a6138136313365a7f7ee792))
- .gitignore - ([ed7d503](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/ed7d503f3c8b6ff0be55b149e1a02729b4097629))

### ⚙️ Miscellaneous Tasks

- *(SonarQube)* Wire - ([be10859](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/be108592780cc12c3e6784737a70921c8b65c966))
- Deps - ([99fba1c](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/99fba1cba195dbbf5bb14c617c1a3bd4124771c5))
- Clean post self-updating - ([4a8615a](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/4a8615a9a33d61a7b71d7a8ceff2695de6bf94bd))
- Act - ([650a1ba](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/650a1bac5a76ebafded4fda7f98e6e81cc7a8426))

## New Contributors ❤️

* @helmut-hoffer-von-ankershoffen made their first contribution

==> oe_python_template-0.2.4.tar.gz: oe_python_template-0.2.4/RELEASE_NOTES.md <==
[🧠 OE Python Template](https://oe-python-template.readthedocs.io/en/latest/)

## [0.2.4](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.2.3..v0.2.4) - 2025-03-07

### ⛰️  Features

- *(mypy)* Introduce static type checker mypy - ([af56e82](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/af56e82581ee5bc157f44e181214751345a4bb52))

### 🎨 Styling

- Remove commented out code - ([246feaa](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/246feaae1287037b78344d3430eff62b147628f4))


## [0.2.3](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.2.2..v0.2.3) - 2025-03-03

### ⛰️  Features

- *(copier)* Introduce tasks - ([db540bc](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/db540bc2907710409c2a23e8a704804bc8e7edda))


## [0.2.2](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.2.1..v0.2.2) - 2025-03-02

### 📚 Documentation

- Update - ([ae71c31](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/ae71c31c917a7439dc24fe9b86c48e38cf1d4c29))


## [0.2.1](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.2.0..v0.2.1) - 2025-03-02

### 📚 Documentation

- Update - ([e718c4c](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/e718c4ca41f566e9668566a3ac8cb92b93d93904))


## [0.2.0](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.1.4..v0.2.0) - 2025-03-02

### 📚 Documentation

- Start to document the template and setup process - ([d37c39c](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/d37c39c518736301aadf1192f9a48c4cfd1ded6e))


## [0.1.4](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.1.3..v0.1.4) - 2025-03-02

### ⛰️  Features

- *(notebooks)* Introduce marimo - ([5d8eb68](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/5d8eb687da96d5111130f67079cc8cbee06ca20e))


## [0.1.3](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.1.2..v0.1.3) - 2025-03-02

### ⚙️ Miscellaneous Tasks

- Other - ([630b5b6](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/630b5b6ca7c2a388c7d1425301f88f0da6e468ad))


## [0.1.2](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.1.1..v0.1.2) - 2025-03-02

### 📚 Documentation

- On template - ([48bdcbe](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/48bdcbe863942bc7dd03bc8e71a50cae968c010c))


## [0.1.1](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.1.0..v0.1.1) - 2025-03-02

### ⚙️ Miscellaneous Tasks

- Arch - ([2cfbe81](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/2cfbe81574646e3dc5c3fa6bf07292d9bf04e1b9))


## [0.1.0](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.0.2..v0.1.0) - 2025-03-02

### ⚙️ Miscellaneous Tasks

- Fix in arch for docker images - ([be8de5b](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/be8de5b1d13587017cdb5b7ecc1bba63ea8245fb))


## [0.0.2] - 2025-03-02

### ⛰️  Features

- Various - ([5b74351](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/5b74351e71e2ca6cb7305bcabdbe802df55c4bae))
- Spike - ([21607c9](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/21607c955cd789dbee6171d287e21f45f039c392))

### 🐛 Bug Fixes

- *(Docker)* Runnability - ([164ab1f](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/164ab1fd7ec517d52587cf7f27f0051bdb6ce319))
- Initial semver - ([9f6fc12](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/9f6fc125c0e24cc0e31580de94db8beb926c8e36))
- Test - ([52faa74](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/52faa74b2d448b13dc12a4d8f706b34334643d00))
- Various - ([f99445f](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/f99445f85b346e0eb69a13c98c2ed311fd4cfafe))
- Chugging along - ([d59fa54](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/d59fa548abc38e88a4605f9588d57bbf9d70d1dc))

### 🚜 Refactor

- *(gitignore)* Section header - ([4ec3972](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/4ec39725978a1e2a3a6138136313365a7f7ee792))
- .gitignore - ([ed7d503](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/ed7d503f3c8b6ff0be55b149e1a02729b4097629))

### ⚙️ Miscellaneous Tasks

- *(SonarQube)* Wire - ([be10859](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/be108592780cc12c3e6784737a70921c8b65c966))
- Deps - ([99fba1c](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/99fba1cba195dbbf5bb14c617c1a3bd4124771c5))
- Clean post self-updating - ([4a8615a](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/4a8615a9a33d61a7b71d7a8ceff2695de6bf94bd))
- Act - ([650a1ba](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/650a1bac5a76ebafded4fda7f98e6e81cc7a8426))

## New Contributors ❤️

* @helmut-hoffer-von-ankershoffen made their first contribution
